@@ -57,7 +57,7 @@ def E(expr,color = "red"):
 
   if isinstance(expr,sy.core.relational.Equality):
     D(expr.subs(DatosList))
-    D(expr.subs(DataRealSymbolList))
+    D((expr.subs(DatosList)).subs(DataRealSymbolList))
   
   if isinstance(expr,list):
     D([expr[0],expr[1].subs(DatosList)])
